@@ -1,6 +1,6 @@
 package App::Info::RDBMS::PostgreSQL;
 
-# $Id: PostgreSQL.pm,v 1.20 2002/06/27 19:59:19 david Exp $
+# $Id: PostgreSQL.pm,v 1.21 2002/06/30 22:18:41 david Exp $
 
 =head1 NAME
 
@@ -44,7 +44,7 @@ use App::Info::RDBMS;
 use App::Info::Util;
 use vars qw(@ISA $VERSION);
 @ISA = qw(App::Info::RDBMS);
-$VERSION = '0.20';
+$VERSION = '0.21';
 
 my $u = App::Info::Util->new;
 
@@ -704,8 +704,8 @@ Feel free to drop me a line if you discover any bugs. Patches welcome.
 
 =head1 AUTHOR
 
-David Wheeler <david@wheeler.net> based on code by Sam Tregar
-<sam@tregar.com>.
+David Wheeler <L<david@wheeler.net|"david@wheeler.net">> based on code by Sam
+Tregar <L<sam@tregar.com|"sam@tregar.com">>.
 
 =head1 SEE ALSO
 
